pub struct MmapReader { /* private fields */ }Expand description
Lector de archivos mapeados en memoria virtual (mmap) con costo cero de asignación inicial.
Implementations
Sourceimpl MmapReader
impl MmapReader
Sourcepub fn open<P: AsRef<Path>>(path: P) -> Result<Self>
pub fn open<P: AsRef<Path>>(path: P) -> Result<Self>
Abre un archivo binario y crea el mapeo de memoria virtual (mmap).
Tiempo de apertura $< 10\text{ ms}$ independientemente del tamaño del archivo.
Sourcepub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_slice(&self) -> &[u8] ⓘ
Obtiene una referencia inmutable a la totalidad del espacio de direcciones mapeado (cero-copia).